<?php
/*
Plugin Name: Golfmate Booking Button for WPBakery Page Builder
Description: The Golfmate plugin enables clubs to add a booking button to any page of your website, ​delivers a simple way to increase bookings for your business.
Version: 1.0.0
Author: golfmate
Author URI: https://golf-mate.com.au/
License: GPLv2 or later
*/

if (!defined('ABSPATH')) die('-1');

class GolfcoachButton {
    function __construct() {
        add_action( 'init', array( $this, 'integrateWithVC' ) );
        add_shortcode( 'golfcoach', array( $this, 'renderMyBartag' ) );
        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
        
    }
    public function integrateWithVC() {
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }
        vc_map( array(
            "name" => __("Golfmate Booking Button", 'vc_extend'),
            "description" => __("Book lessons with a specific coach", 'vc_extend'),
            "base" => "golfcoach",
            "class" => "coach-content-container",
            "show_settings_on_create" => true,
            "controls" => "full",
            "front_enqueue_js" => plugins_url('assets/coach_btn.js', __FILE__),
            "front_enqueue_css" =>  plugins_url('assets/custom_btn_editor.css', __FILE__),
            "icon" => plugins_url('assets/golfcoachlogo.png', __FILE__),
            "category" => __('Content', 'js_composer'),
            "params" => array(
                array(
                  "type" => "textfield",
                  "class" => "coach_id_area",
                  "edit_field_class" => "vc_col-sm-6",
                  "heading" => __("Mobile number", 'vc_extend'),
                  "description" => "The number used to create Golfmate account, e.g. 0412345678",
                  "param_name" => "phone",
                  "value" => __("0478636866", 'vc_extend'),
                ),
                array(
                  "type" => "textfield",
                  "edit_field_class" => "vc_col-sm-6",
                  "class" => "coach_content_area",
                  "description" => "Text on the button",
                  "heading" => __("Text", 'vc_extend'),
                  "param_name" => "content",
                  "value" => __("Book", 'vc_extend'),
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "description" => "Select button display style.",
                  "heading" => __("Style", 'vc_extend'),
                  "param_name" => "style_class",
                  "value" => array(
                    "Modern" => "modern-btn",
                    "Classic" => "classic-btn",
                    "Flat" => "flat-btn",
                    "Outline" => "outline-btn",
                    "Custom" => "custom"
                  ), 
                ),
                array(
                  'type' => 'colorpicker',
                  'heading' => esc_html__( 'Background', 'js_composer' ),
                  'param_name' => 'backgroundcolor',
                  "description" => "Select button color.",
                  'description' => esc_html__( 'Select custom background color for your element.', 'js_composer' ),
                  'dependency' => array(
                    'element' => 'style_class',
                    'value' => array( 'custom' ),
                  ),
                  'edit_field_class' => 'vc_col-sm-6',
                  'std' => '#ededed',
                  "value" => '#ededed',
                ),
                array(
                  'type' => 'colorpicker',
                  'heading' => esc_html__( 'Text', 'js_composer' ),
                  'param_name' => 'color',
                  'description' => esc_html__( 'Select custom text color for your element.', 'js_composer' ),
                  'dependency' => array(
                    'element' => 'style_class',
                    'value' => array( 'custom' ),
                  ),
                  'edit_field_class' => 'vc_col-sm-6',
                  'std' => '#666',
                  "value" => '#666',
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "class" => "",
                  "description" => "Select button shape.",
                  "heading" => __("Shape", 'vc_extend'),
                  "param_name" => "shape",
                  "value" => array(
                    "Rounded" => "rounded-btn",
                    "Square" => "square-btn",
                  ), 
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "description" => "Select button display size.",
                  "class" => "",
                  "heading" => __("Size", 'vc_extend'),
                  "param_name" => "size",
                  "value" => array( 
                    "Normal" => "md-btn",
                    "Mini" => "xs-btn",
                    "Small" => "sm-btn",
                    "Large" => "lg-btn",
                  ), 
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "class" => "",
                  "heading" => __("Alignment", 'vc_extend'),
                  "description" => "Select button alignment.",
                  "param_name" => "alignment",
                  "value" => array(
                    "Inline" => "inline",
                    "Left" => "flex-start",
                    "Right" => "flex-end",
                    "Center" => "center"
                  ), 
                ),
            )
        ) );
    }


    public function renderMyBartag( $atts, $content = null ) {

      extract( shortcode_atts( array(
        'phone' => '0478636866',
        'color' => '#666',
        'backgroundcolor' => '#ededed',
        'style_class' => 'modern-btn',
        'shape' => 'rounded-btn',
        'size' => 'md-btn',
        'alignment' => 'inline',
      ), $atts ) );
      $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
      $clubList_url = "https://web.golf-mate.com.au/coach/list?area=61&phone={$phone}";
      $coach_url = "https://web.golf-mate.com.au/coach/profile?area=61&phone={$phone}";
      $style = "color:{$color};background: {$backgroundcolor};";
      if($alignment == 'inline') {
        $alignText = 'flex';
        $alignSub = 'flex-start';
      } else {
        $alignText = 'flex';
        $alignSub = $alignment;
      }
      $alignStyle = "display:{$alignText};justify-content:{$alignSub};align-items:center;";
      if($style_class == 'custom') {
        $output = "<div class=\" golfmate-button-container \" style={$alignStyle} ><a  href='{$coach_url}' target=_blank><button class=\"golfcoach-button {$style_class} {$shape} {$size}\" style='{$style}' data-foo='${foo}'><span>{$content}</span></button></a></div>";
      } else {
        $output = "<div class=\"golfmate-button-container\" style={$alignStyle} ><a  href='{$coach_url}' target=_blank><button class=\"golfcoach-button {$style_class} {$style_class} {$shape} {$size}\" data-foo='${foo}'><span>{$content}</span></button></a></div>";
      }
      return $output;
    }

    public function loadCssAndJs() {
      wp_register_style( 'vc_extend_style', plugins_url('assets/coach_btn_style_023.css', __FILE__) );
      wp_enqueue_style( 'vc_extend_style' );

      
    }


    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="https://codecanyon.net/item/visual-composer-page-builder-for-wordpress/242431?ref=mixey" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'vc_extend'), $plugin_data['Name']).'</p>
        </div>';
    }
}


class GolfcoachButtonList {
    function __construct() {
        add_action( 'init', array( $this, 'integrateWithVC' ) );
 
        add_shortcode( 'golfcoach_list', array( $this, 'renderMyBartag' ) );

        add_action( 'wp_enqueue_scripts', array( $this, 'loadCssAndJs' ) );
    }
 
    public function integrateWithVC() {
        // Check if WPBakery Page Builder is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Extend WPBakery Page Builder is required
            add_action('admin_notices', array( $this, 'showVcVersionNotice' ));
            return;
        }

        vc_map( array(
            "name" => __("Golfmate List Button", 'vc_extend'),
            "description" => __("List all available coaches at your club ", 'vc_extend'),
            "base" => "golfcoach_list",
            "class" => "coach-club-container",
            "front_enqueue_js" => plugins_url('assets/coach_btn.js', __FILE__),
            "front_enqueue_css" =>  plugins_url('assets/custom_btn_editor.css', __FILE__),
            "show_settings_on_create" => true,
            "controls" => "full",
            "icon" => plugins_url('assets/golfcoachlogo.png', __FILE__), // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Content', 'js_composer'),
            "params" => array(
                array(
                  "type" => "textfield",
                  "class" => "coach_id_area",
                  "edit_field_class" => "vc_col-sm-6",
                  "heading" => __("Mobile number", 'vc_extend'),
                  "description" => "The number used to create Golfmate account, e.g. 0412345678",
                  "param_name" => "phone",
                  "value" => __("0478636866", 'vc_extend'),
                ),
                array(
                  "type" => "textfield",
                  "edit_field_class" => "vc_col-sm-6",
                  "class" => "coach_content_area",
                  "description" => "Text on the button",
                  "heading" => __("Text", 'vc_extend'),
                  "param_name" => "content",
                  "value" => __("Book", 'vc_extend'),
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "class" => "",
                  "description" => "Select button display style.",
                  "heading" => __("Style", 'vc_extend'),
                  "param_name" => "style_class",
                  "value" => array(
                    "Modern" => "modern-btn",
                    "Classic" => "classic-btn",
                    "Flat" => "flat-btn",
                    "Outline" => "outline-btn",
                    // esc_html__( 'Custom', 'js_composer' ) => 'custom'
                    "Custom" => "custom"
                  ), 
                ),
                array(
                  'type' => 'colorpicker',
                  'heading' => esc_html__( 'Background', 'js_composer' ),
                  "description" => "Select button color.",
                  'param_name' => 'backgroundcolor',
                  'description' => esc_html__( 'Select custom background color for your element.', 'js_composer' ),
                  'dependency' => array(
                    'element' => 'style_class',
                    'value' => array( 'custom' ),
                  ),
                  'edit_field_class' => 'vc_col-sm-7',
                  'std' => '#ededed',
                  "value" => '#ededed',
                ),
                array(
                  'type' => 'colorpicker',
                  'heading' => esc_html__( 'Text', 'js_composer' ),
                  'param_name' => 'color',
                  'description' => esc_html__( 'Select custom text color for your element.', 'js_composer' ),
                  'dependency' => array(
                    'element' => 'style_class',
                    'value' => array( 'custom' ),
                  ),
                  'edit_field_class' => 'vc_col-sm-7',
                  'std' => '#666',
                  "value" => '#666',
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "class" => "",
                  "description" => "Select button shape.",
                  "heading" => __("Shape", 'vc_extend'),
                  "param_name" => "shape",
                  "value" => array(
                    "Rounded" => "rounded-btn",
                    "Square" => "square-btn",
                  ), 
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "description" => "Select button display size.",
                  "class" => "",
                  "heading" => __("Size", 'vc_extend'),
                  "param_name" => "size",
                  "value" => array(
                    "Normal" => "md-btn",
                    "Mini" => "xs-btn",
                    "Small" => "sm-btn",
                    "Large" => "lg-btn",
                  ), 
                ),
                array(
                  "type" => "dropdown",
                  "holder" => "div",
                  "description" => "Select button alignment.",
                  "class" => "",
                  "heading" => __("Alignment", 'vc_extend'),
                  "param_name" => "alignment",
                  "value" => array(
                    "Inline" => "inline",
                    "Left" => "flex-start",
                    "Right" => "flex-end",
                    "Center" => "center"
                  ), 
                ),
            )
        ) );
    }
    
    public function renderMyBartag( $atts, $content = null ) {
      extract( shortcode_atts( array(
        'phone' => '0478636866',
        'color' => '#666',
        'backgroundcolor' => '#ededed',
        'style_class' => 'modern-btn',
        'shape' => 'rounded-btn',
        'size' => 'md-btn',
        'alignment' => 'inline',
      ), $atts ) );
      $content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content
      $clubList_url = "https://web.golf-mate.com.au/coach/list?area=61&phone={$phone}";
      $coach_url = "https://web.golf-mate.com.au/coach/profile?area=61&phone={$phone}";
      $style = "color:{$color};background: {$backgroundcolor};";
      if($alignment == 'inline') {
        $alignText = 'flex';
        $alignSub = 'flex-start';
      } else {
        $alignText = 'flex';
        $alignSub = $alignment;
      }
      $alignStyle = "display:{$alignText};justify-content:{$alignSub};align-items:center;";
      if($style_class == 'custom') {
        $output = "<div class=\"golfmate-button-container\" style={$alignStyle} ><a  href='{$clubList_url}' target=_blank><button class=\"golfcoach-button {$style_class} {$shape} {$size}\" style='{$style}' data-foo='${foo}'><span>{$content}</span></button></a></div>";
      } else {
        $output = "<div class=\"golfmate-button-container\" style={$alignStyle} ><a  href='{$clubList_url}' target=_blank><button class=\"golfcoach-button {$style_class} {$shape} {$size}\" data-foo='${foo}'><span>{$content}</span></button></a></div>";
      }
      return $output;
    }

    public function loadCssAndJs() {
      wp_register_style( 'vc_extend_style', plugins_url('assets/coach_btn_style_023.css', __FILE__) );
      wp_enqueue_style( 'vc_extend_style' );

    }


    public function showVcVersionNotice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="https://codecanyon.net/item/visual-composer-page-builder-for-wordpress/242431?ref=mixey" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'vc_extend'), $plugin_data['Name']).'</p>
        </div>';
    }
}

new GolfcoachButton();
new GolfcoachButtonList();
?>